import { type Metadata } from 'next';
import Image from 'next/image';
import dynamic from 'next/dynamic';

import { Container } from '@/components/Container';
import logoImage from '@/images/logo.png';

export const metadata: Metadata = {
  title: 'Donate',
  description: 'Donate to the West Sound Community Club.',
};

export default function Donate() {
  // Dynamic import since DontationPayment uses `document`
  const DontationPayment = dynamic(
    () => {
      return import('./payment');
    },
    { ssr: false },
  );

  return (
    <Container className="mx-auto mt-16 max-w-3xl sm:mt-32">
      <div className="px-2.5">
        <Image
          src={logoImage}
          alt=""
          sizes="(min-width: 1024px) 32rem, 20rem"
        />
      </div>
      <div className="my-6 space-y-7 text-base text-zinc-600">
        <p>
          Your donation to the West Sound Community Club helps keep the hall
          alive for the next generation.
        </p>

        <p>
          The West Sound Community Club is a nonprofit, tax-exempt corporation
          under Section 501(c)3 of the Internal Revenue Code. Your donations are
          tax-deductible.
        </p>
      </div>
      <DontationPayment />
    </Container>
  );
}
